@@ -7,5 +7,4 @@ import sys
 
 import real_edit
 
-real_edit.EditDisplay(os.path.join(
-    os.path.dirname(sys.argv[0]), 'edit_text.txt')).main()
+real_edit.EditDisplay(os.path.join(os.path.dirname(sys.argv[0]), "edit_text.txt")).main()
