@@ -3,8 +3,8 @@ from __future__ import annotations
 import urwid
 
 
-def exit_on_q(key):
-    if key in ("q", "Q"):
+def exit_on_q(key: str) -> None:
+    if key in {"q", "Q"}:
         raise urwid.ExitMainLoop()
 
 
