@@ -27,9 +27,13 @@ in monochrome, 16 color, 88 color, 256 color, and 24-bit (true) color modes.
 from __future__ import annotations
 
 import re
+import typing
 
 import urwid
 
+if typing.TYPE_CHECKING:
+    from typing_extensions import Literal
+
 CHART_TRUE = """
 #e50000#e51000#e52000#e53000#e54000#e55000#e56000#e57000#e58000#e59000\
 #e5a000#e5b100#e5c100#e5d100#e5e100#d9e500#c9e500#b9e500#a9e500#99e500\
@@ -253,7 +257,7 @@ SHORT_ATTR = 4  # length of short high-colour descriptions which may
 # be packed one after the next
 
 
-def parse_chart(chart, convert):
+def parse_chart(chart: str, convert):
     """
     Convert string chart into text markup with the correct attributes.
 
@@ -284,13 +288,13 @@ def parse_chart(chart, convert):
                 entry = ""
             attr, text = attrtext
             if chart == CHART_TRUE:
-                out.append((attr, "\u2584"))
+                out.append((attr, "▄"))
             else:
                 out.append((attr, text.ljust(elen)))
     return out
 
 
-def foreground_chart(chart, background, colors):
+def foreground_chart(chart: str, background, colors: Literal[1, 16, 88, 256, 16777216]):
     """
     Create text markup for a foreground colour chart
 
@@ -309,7 +313,7 @@ def foreground_chart(chart, background, colors):
     return parse_chart(chart, convert_foreground)
 
 
-def background_chart(chart, foreground, colors):
+def background_chart(chart: str, foreground, colors: Literal[1, 16, 88, 256, 16777216]):
     """
     Create text markup for a background colour chart
 
@@ -329,14 +333,14 @@ def background_chart(chart, foreground, colors):
         # fix 8 <= colour < 16
         if colors > 16 and attr.background_basic and attr.background_number >= 8:
             # use high-colour with same number
-            entry = "h%d" % attr.background_number
+            entry = f"h{attr.background_number:d}"
             attr = urwid.AttrSpec(foreground, entry, colors)
         return attr, entry
 
     return parse_chart(chart, convert_background)
 
 
-def main():
+def main() -> None:
     palette = [
         ("header", "black,underline", "light gray", "standout,underline", "black,underline", "#88a"),
         ("panel", "light gray", "dark blue", "", "#ffd", "#00a"),
@@ -352,11 +356,11 @@ def main():
     mode_radio_buttons = []
     chart_radio_buttons = []
 
-    def fcs(widget):
+    def fcs(widget) -> urwid.AttrMap:
         # wrap widgets that can take focus
         return urwid.AttrMap(widget, None, "focus")
 
-    def set_mode(colors, is_foreground_chart):
+    def set_mode(colors: int, is_foreground_chart: bool) -> None:
         # set terminal mode and redraw chart
         screen.set_terminal_properties(colors)
         screen.reset_default_terminal_palette()
@@ -365,27 +369,27 @@ def main():
         if colors == 1:
             lb[chart_offset] = urwid.Divider()
         else:
-            chart = {16: CHART_16, 88: CHART_88, 256: CHART_256, 2**24: CHART_TRUE}[colors]
+            chart: str = {16: CHART_16, 88: CHART_88, 256: CHART_256, 2**24: CHART_TRUE}[colors]
             txt = chart_fn(chart, "default", colors)
-            lb[chart_offset] = urwid.Text(txt, wrap="clip")
+            lb[chart_offset] = urwid.Text(txt, wrap=urwid.CLIP)
 
-    def on_mode_change(rb, state, colors):
+    def on_mode_change(colors: int, rb: urwid.RadioButton, state: bool) -> None:
         # if this radio button is checked
         if state:
             is_foreground_chart = chart_radio_buttons[0].state
             set_mode(colors, is_foreground_chart)
 
-    def mode_rb(text, colors, state=False):
+    def mode_rb(text: str, colors: int, state: bool = False) -> urwid.AttrMap:
         # mode radio buttons
         rb = urwid.RadioButton(mode_radio_buttons, text, state)
-        urwid.connect_signal(rb, "change", on_mode_change, colors)
+        urwid.connect_signal(rb, "change", on_mode_change, user_args=(colors,))
         return fcs(rb)
 
-    def on_chart_change(rb, state):
+    def on_chart_change(rb: urwid.RadioButton, state: bool) -> None:
         # handle foreground check box state change
         set_mode(screen.colors, state)
 
-    def click_exit(button):
+    def click_exit(button) -> typing.NoReturn:
         raise urwid.ExitMainLoop()
 
     lb.extend(
@@ -423,8 +427,8 @@ def main():
 
     set_mode(16, True)  # displays the chart
 
-    def unhandled_input(key):
-        if key in ("Q", "q", "esc"):
+    def unhandled_input(key: str | tuple[str, int, int, int]) -> None:
+        if key in {"Q", "q", "esc"}:
             raise urwid.ExitMainLoop()
 
     urwid.MainLoop(urwid.ListBox(lb), screen=screen, unhandled_input=unhandled_input).run()
