@@ -189,11 +189,11 @@ class TwistedScreen(Screen):
 
     # Urwid Screen API
 
-    def get_cols_rows(self):
+    def get_cols_rows(self) -> tuple[int, int]:
         """Get the size of the terminal as (cols, rows)"""
         return self.terminalProtocol.width, self.terminalProtocol.height
 
-    def draw_screen(self, maxres, r):
+    def draw_screen(self, size: tuple[int, int], canvas: urwid.Canvas) -> None:
         """Render a canvas to the terminal.
 
         The canvas contains all the information required to render the Urwid
@@ -201,10 +201,10 @@ class TwistedScreen(Screen):
         tuples. This very simple implementation iterates each row and simply
         writes it out.
         """
-        (maxcol, maxrow) = maxres
+        (_maxcol, _maxrow) = size
         # self.terminal.eraseDisplay()
         lasta = None
-        for i, row in enumerate(r.content()):
+        for i, row in enumerate(canvas.content()):
             self.terminal.cursorPosition(0, i)
             for attr, _cs, text in row:
                 if attr != lasta:
@@ -213,7 +213,7 @@ class TwistedScreen(Screen):
                 # if cs or attr:
                 #    print(cs, attr)
                 self.write(text)
-        cursor = r.get_cursor()
+        cursor = canvas.get_cursor()
         if cursor is not None:
             self.terminal.cursorPosition(*cursor)
 
@@ -400,7 +400,7 @@ class UrwidTerminalSession(TerminalSession):
 
     def windowChanged(self, dimensions):
         """Called when the window size has changed."""
-        (h, w, x, y) = dimensions
+        (h, w, _x, _y) = dimensions
         self.chained_protocol.terminalProtocol.terminalSize(h, w)
 
 
