@@ -35,13 +35,12 @@ import socket
 import sys
 import typing
 
-from urwid import signals, util
+from urwid import signals, str_util, util
 
 from . import escape
 from .common import UNPRINTABLE_TRANS_TABLE, UPDATE_PALETTE_ENTRY, AttrSpec, BaseScreen, RealTerminal
 
 if typing.TYPE_CHECKING:
-    import io
     from collections.abc import Callable, Iterable
     from types import FrameType
 
@@ -54,7 +53,7 @@ IS_WSL = (sys.platform == "linux") and ("wsl" in platform.platform().lower())
 
 
 class Screen(BaseScreen, RealTerminal):
-    def __init__(self, input: io.IOBase, output: io.IOBase):  # noqa: A002
+    def __init__(self, input: typing.IO, output: typing.IO) -> None:  # noqa: A002  # pylint: disable=redefined-builtin
         """Initialize a screen that directly prints escape codes to an output
         terminal.
         """
@@ -116,7 +115,7 @@ class Screen(BaseScreen, RealTerminal):
         self.screen_buf = None
 
     @property
-    def _term_input_io(self) -> io.IOBase | None:
+    def _term_input_io(self) -> typing.IO | None:
         if hasattr(self._term_input_file, "fileno"):
             return self._term_input_file
         return None
@@ -173,7 +172,7 @@ class Screen(BaseScreen, RealTerminal):
         After calling this function get_input will include mouse
         click events along with keystrokes.
         """
-        enable = bool(enable)
+        enable = bool(enable)  # noqa: FURB123,RUF100
         if enable == self._mouse_tracking_enabled:
             return
 
@@ -310,7 +309,7 @@ class Screen(BaseScreen, RealTerminal):
             return keys, raw
         return keys
 
-    def get_input_descriptors(self) -> list[socket.socket | io.IOBase | typing.IO | int]:
+    def get_input_descriptors(self) -> list[socket.socket | typing.IO | int]:
         """
         Return a list of integer file descriptors that should be
         polled in external event loops to check for user input.
@@ -323,7 +322,7 @@ class Screen(BaseScreen, RealTerminal):
         if not self._started:
             return []
 
-        fd_list = [self._resize_pipe_rd]
+        fd_list: list[socket.socket | typing.IO | int] = [self._resize_pipe_rd]
         input_io = self._term_input_io
         if input_io is not None:
             fd_list.append(input_io)
@@ -355,8 +354,7 @@ class Screen(BaseScreen, RealTerminal):
 
     def _make_legacy_input_wrapper(self, event_loop, callback):
         """
-        Support old Screen classes that still have a get_input_nonblocking and
-        expect it to work.
+        Support old Screen classes that still have a get_input_nonblocking and expect it to work.
         """
 
         @functools.wraps(callback)
@@ -364,7 +362,7 @@ class Screen(BaseScreen, RealTerminal):
             if self._input_timeout:
                 event_loop.remove_alarm(self._input_timeout)
                 self._input_timeout = None
-            timeout, keys, raw = self.get_input_nonblocking()
+            timeout, keys, raw = self.get_input_nonblocking()  # pylint: disable=no-member  # should we deprecate?
             if timeout is not None:
                 self._input_timeout = event_loop.alarm(timeout, wrapper)
 
@@ -528,7 +526,7 @@ class Screen(BaseScreen, RealTerminal):
                 break
         self._setup_G1_done = True
 
-    def draw_screen(self, size: tuple[int, int], r: Canvas) -> None:
+    def draw_screen(self, size: tuple[int, int], canvas: Canvas) -> None:
         """Paint screen with rendered canvas."""
 
         def set_cursor_home() -> str:
@@ -546,15 +544,15 @@ class Screen(BaseScreen, RealTerminal):
         def is_blank_row(row: list[tuple[object, Literal["0", "U"] | None], bytes]) -> bool:
             if len(row) > 1:
                 return False
-            if row[0][2].strip():
-                return False
-            return True
+            return not row[0][2].strip()
 
-        def attr_to_escape(a: AttrSpec | str) -> str:
+        def attr_to_escape(a: AttrSpec | str | None) -> str:
             if a in self._pal_escape:
                 return self._pal_escape[a]
             if isinstance(a, AttrSpec):
                 return self._attrspec_to_escape(a)
+            if a is None:
+                return self._attrspec_to_escape(AttrSpec("default", "default"))
             # undefined attributes use default/default
             self.logger.debug(f"Undefined attribute: {a!r}")
             return self._attrspec_to_escape(AttrSpec("default", "default"))
@@ -572,11 +570,11 @@ class Screen(BaseScreen, RealTerminal):
         if not self._started:
             raise RuntimeError
 
-        if maxrow != r.rows():
+        if maxrow != canvas.rows():
             raise ValueError(maxrow)
 
         # quick return if nothing has changed
-        if self.screen_buf and r is self._screen_buf_canvas:
+        if self.screen_buf and canvas is self._screen_buf_canvas:
             return
 
         self._setup_G1()
@@ -603,7 +601,7 @@ class Screen(BaseScreen, RealTerminal):
             osb = self.screen_buf
         else:
             osb = []
-        sb = []
+        sb: list[list[tuple[object, Literal["0", "U"] | None, bytes]]] = []
         cy = self._cy
         y = -1
 
@@ -614,7 +612,7 @@ class Screen(BaseScreen, RealTerminal):
         first = True
         last_charset_flag = None
 
-        for row in r.content():
+        for row in canvas.content():
             y += 1
             if osb and y < len(osb) and osb[y] == row:
                 # this row of the screen buffer matches what is
@@ -684,7 +682,7 @@ class Screen(BaseScreen, RealTerminal):
                 if isinstance(inserttext, bytes):
                     inserttext = inserttext.decode(encoding)
 
-                output.extend(("\x08" * back, ias))
+                output.extend(("\x08" * back, ias))  # pylint: disable=used-before-assignment  # defined in `if row`
 
                 if encoding != "utf-8":
                     if cs is None:
@@ -699,7 +697,7 @@ class Screen(BaseScreen, RealTerminal):
                 if not IS_WINDOWS:
                     output += [escape.INSERT_ON, inserttext, escape.INSERT_OFF]
                 else:
-                    output += [f"{escape.ESC}[{util.calc_width(inserttext, 0, len(inserttext))}@", inserttext]
+                    output += [f"{escape.ESC}[{str_util.calc_width(inserttext, 0, len(inserttext))}@", inserttext]
 
                 if encoding != "utf-8" and cs == "U":
                     output.append(escape.IBMPC_OFF)
@@ -707,8 +705,8 @@ class Screen(BaseScreen, RealTerminal):
             if whitespace_at_end:
                 output.append(escape.ERASE_IN_LINE_RIGHT)
 
-        if r.cursor is not None:
-            x, y = r.cursor
+        if canvas.cursor is not None:
+            x, y = canvas.cursor
             output += [set_cursor_position(x, y), escape.SHOW_CURSOR]
             self._cy = y
 
@@ -727,9 +725,13 @@ class Screen(BaseScreen, RealTerminal):
                 raise
 
         self.screen_buf = sb
-        self._screen_buf_canvas = r
+        self._screen_buf_canvas = canvas
 
-    def _last_row(self, row):
+    def _last_row(self, row: list[tuple[object, Literal["0", "U"] | None, bytes]]) -> tuple[
+        list[tuple[object, Literal["0", "U"] | None, bytes]],
+        int,
+        tuple[object, Literal["0", "U"] | None, bytes],
+    ]:
         """On the last row we need to slide the bottom right character
         into place. Calculate the new line, attr and an insert sequence
         to do that.
@@ -742,24 +744,24 @@ class Screen(BaseScreen, RealTerminal):
 
         new_row = row[:-1]
         z_attr, z_cs, last_text = row[-1]
-        last_cols = util.calc_width(last_text, 0, len(last_text))
-        last_offs, z_col = util.calc_text_pos(last_text, 0, len(last_text), last_cols - 1)
+        last_cols = str_util.calc_width(last_text, 0, len(last_text))
+        last_offs, z_col = str_util.calc_text_pos(last_text, 0, len(last_text), last_cols - 1)
         if last_offs == 0:
             z_text = last_text
             del new_row[-1]
             # we need another segment
             y_attr, y_cs, nlast_text = row[-2]
-            nlast_cols = util.calc_width(nlast_text, 0, len(nlast_text))
+            nlast_cols = str_util.calc_width(nlast_text, 0, len(nlast_text))
             z_col += nlast_cols
-            nlast_offs, y_col = util.calc_text_pos(nlast_text, 0, len(nlast_text), nlast_cols - 1)
+            nlast_offs, y_col = str_util.calc_text_pos(nlast_text, 0, len(nlast_text), nlast_cols - 1)
             y_text = nlast_text[nlast_offs:]
             if nlast_offs:
                 new_row.append((y_attr, y_cs, nlast_text[:nlast_offs]))
         else:
             z_text = last_text[last_offs:]
             y_attr, y_cs = z_attr, z_cs
-            nlast_cols = util.calc_width(last_text, 0, last_offs)
-            nlast_offs, y_col = util.calc_text_pos(last_text, 0, last_offs, nlast_cols - 1)
+            nlast_cols = str_util.calc_width(last_text, 0, last_offs)
+            nlast_offs, y_col = str_util.calc_text_pos(last_text, 0, last_offs, nlast_cols - 1)
             y_text = last_text[nlast_offs:last_offs]
             if nlast_offs:
                 new_row.append((y_attr, y_cs, last_text[:nlast_offs]))
