@@ -29,17 +29,14 @@ import sys
 import typing
 from collections.abc import MutableMapping, Sequence
 
-if typing.TYPE_CHECKING:
-    from collections.abc import Collection, Iterable
+from urwid import str_util
 
-try:
-    from urwid import str_util
-except ImportError:
-    from urwid import old_str_util as str_util
+if typing.TYPE_CHECKING:
+    from collections.abc import Iterable
 
 # NOTE: because of circular imports (urwid.util -> urwid.escape -> urwid.util)
 # from urwid.util import is_mouse_event -- will not work here
-import urwid.util
+import urwid.util  # isort: skip  # pylint: disable=wrong-import-position
 
 IS_WINDOWS = sys.platform == "win32"
 
@@ -88,6 +85,8 @@ input_sequences = [
     ("[F", "end"),
     ("[G", "5"),
     ("[H", "home"),
+    ("[I", "focus in"),
+    ("[O", "focus out"),
     ("[1~", "home"),
     ("[2~", "insert"),
     ("[3~", "delete"),
@@ -203,7 +202,7 @@ class KeyqueueTrie:
         s: str,
         result: str,
     ) -> None:
-        if not isinstance(root, MutableMapping) or len(s) <= 0:
+        if not isinstance(root, MutableMapping) or not s:
             raise RuntimeError("trie conflict detected")
 
         if ord(s[0]) in root:
@@ -215,7 +214,6 @@ class KeyqueueTrie:
             self.add(d, s[1:], result)
             return
         root[ord(s)] = result
-        return
 
     def get(self, keys, more_available: bool):
         result = self.get_recurse(self.data, keys, more_available)
@@ -229,7 +227,7 @@ class KeyqueueTrie:
             MutableMapping[int, str | MutableMapping[int, str | MutableMapping[int, str]]]
             | typing.Literal["mouse", "sgrmouse"]
         ),
-        keys: Collection[int],
+        keys: Sequence[int],
         more_available: bool,
     ):
         if not isinstance(root, MutableMapping):
@@ -249,7 +247,7 @@ class KeyqueueTrie:
             return None
         return self.get_recurse(root[keys[0]], keys[1:], more_available)
 
-    def read_mouse_info(self, keys: Collection[int], more_available: bool):
+    def read_mouse_info(self, keys: Sequence[int], more_available: bool):
         if len(keys) < 3:
             if more_available:
                 raise MoreInputRequired()
@@ -288,7 +286,7 @@ class KeyqueueTrie:
 
         return ((f"{prefix}mouse {action}", button, x, y), keys[3:])
 
-    def read_sgrmouse_info(self, keys: Collection[int], more_available: bool):
+    def read_sgrmouse_info(self, keys: Sequence[int], more_available: bool):
         # Helpful links:
         # https://stackoverflow.com/questions/5966903/how-to-get-mousemove-and-mouseclick-in-bash
         # http://invisible-island.net/xterm/ctlseqs/ctlseqs.pdf
@@ -314,17 +312,15 @@ class KeyqueueTrie:
 
         (b, x, y) = (int(val) for val in value[:-1].split(";"))
         action = value[-1]
-
-        # shift, etc. is not communicated on my machine, so I
-        # can't and won't be able to add support for it.
-        # Double and triple clicks are not supported as well. They can be
-        # implemented by using a timer. This timer can check if the last
-        # registered click is below a certain threshold. This threshold
-        # is normally set in the operating system itself, so setting one
-        # here will cause an inconsistent behaviour. I do not plan to use
-        # that feature, so I won't implement it.
+        # Double and triple clicks are not supported.
+        # They can be implemented by using a timer.
+        # This timer can check if the last registered click is below a certain threshold.
+        # This threshold is normally set in the operating system itself,
+        # so setting one here will cause an inconsistent behaviour.
 
         prefixes = []
+        if b & 4:
+            prefixes.append("shift ")
         if b & 8:
             prefixes.append("meta ")
         if b & 16:
@@ -580,6 +576,9 @@ RESTORE_NORMAL_BUFFER = f"{ESC}[?1049l"
 ENABLE_BRACKETED_PASTE_MODE = f"{ESC}[?2004h"
 DISABLE_BRACKETED_PASTE_MODE = f"{ESC}[?2004l"
 
+ENABLE_FOCUS_REPORTING = f"{ESC}[?1004h"
+DISABLE_FOCUS_REPORTING = f"{ESC}[?1004l"
+
 # RESET_SCROLL_REGION = ESC+"[;r"
 # RESET = ESC+"c"
 
