@@ -25,6 +25,7 @@ from __future__ import annotations
 
 import dataclasses
 import glob
+import html
 import os
 import pathlib
 import random
@@ -37,7 +38,8 @@ import tempfile
 import typing
 from contextlib import suppress
 
-from urwid.util import StoppingContext, calc_text_pos, calc_width, move_next_char
+from urwid.str_util import calc_text_pos, calc_width, move_next_char
+from urwid.util import StoppingContext, get_encoding
 
 from .common import BaseScreen
 
@@ -120,17 +122,17 @@ Status: <span id="status">Set up</span>
 
 
 class Screen(BaseScreen):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__()
         self.palette = {}
         self.has_color = True
         self._started = False
 
     @property
-    def started(self):
+    def started(self) -> bool:
         return self._started
 
-    def register_palette(self, palette):
+    def register_palette(self, palette) -> None:
         """Register a list of palette entries.
 
         palette -- list of (name, foreground, background) or
@@ -176,11 +178,9 @@ class Screen(BaseScreen):
 
     def set_mouse_tracking(self, enable: bool = True) -> None:
         """Not yet implemented"""
-        pass
 
     def tty_signal_keys(self, *args, **vargs):
         """Do nothing."""
-        pass
 
     def start(self) -> StoppingContext:
         """
@@ -239,7 +239,7 @@ class Screen(BaseScreen):
 
         return StoppingContext(self)
 
-    def stop(self):
+    def stop(self) -> None:
         """
         Restore settings and clean up.
         """
@@ -253,10 +253,10 @@ class Screen(BaseScreen):
         self._cleanup_pipe()
         self._started = False
 
-    def set_input_timeouts(self, *args):
+    def set_input_timeouts(self, *args: typing.Any) -> None:
         pass
 
-    def _close_connection(self):
+    def _close_connection(self) -> None:
         if self.update_method == "polling child":
             self.server_socket.settimeout(0)
             sock, _addr = self.server_socket.accept()
@@ -267,7 +267,7 @@ class Screen(BaseScreen):
             sys.stdout.write("\r\nZ\r\n--ZZ--\r\n")
             sys.stdout.flush()
 
-    def _cleanup_pipe(self, *args):
+    def _cleanup_pipe(self, *args) -> None:
         if not self.pipe_name:
             return
         # XXX which exceptions does this actually raise? EnvironmentError?
@@ -275,16 +275,14 @@ class Screen(BaseScreen):
             os.remove(f"{self.pipe_name}.in")
             os.remove(f"{self.pipe_name}.update")
 
-    def _set_screen_size(self, cols, rows):
+    def _set_screen_size(self, cols: int, rows: int) -> None:
         """Set the screen size (within max size)."""
 
-        if cols > MAX_COLS:
-            cols = MAX_COLS
-        if rows > MAX_ROWS:
-            rows = MAX_ROWS
+        cols = min(cols, MAX_COLS)
+        rows = min(rows, MAX_ROWS)
         self.screen_size = cols, rows
 
-    def draw_screen(self, size: tuple[int, int], r: Canvas):
+    def draw_screen(self, size: tuple[int, int], canvas: Canvas) -> None:
         """Send a screen update to the client."""
 
         (cols, rows) = size
@@ -309,24 +307,24 @@ class Screen(BaseScreen):
             send("\r\n")
             self.content_head = ""
 
-        if r.rows() != rows:
+        if canvas.rows() != rows:
             raise ValueError(rows)
 
-        if r.cursor is not None:
-            cx, cy = r.cursor
+        if canvas.cursor is not None:
+            cx, cy = canvas.cursor
         else:
             cx = cy = None
 
         new_screen = {}
 
         y = -1
-        for row in r.content():
+        for row in canvas.content():
             y += 1
-            l_row = list(row)
+            l_row = tuple((attr_, line.decode(get_encoding())) for attr_, _, line in row)
 
             line = []
 
-            sig = tuple(l_row)
+            sig = l_row
             if y == cy:
                 sig = (*sig, cx)
             new_screen[sig] = [*new_screen.get(sig, []), y]
@@ -336,11 +334,11 @@ class Screen(BaseScreen):
                     old_line = y
                 else:
                     old_line = old_line_numbers[0]
-                send("<%d\n" % old_line)
+                send(f"<{old_line:d}\n")
                 continue
 
             col = 0
-            for a, _cs, run in l_row:
+            for a, run in l_row:
                 t_run = run.translate(_trans_table)
                 if a is None:
                     fg, bg, _mono = "black", "light gray", None
@@ -374,16 +372,15 @@ class Screen(BaseScreen):
 
         signal.alarm(ALARM_DELAY)
 
-    def clear(self):
+    def clear(self) -> None:
         """
         Force the screen to be completely repainted on the next
         call to draw_screen().
 
         (does nothing for web_display)
         """
-        pass
 
-    def _fork_child(self):
+    def _fork_child(self) -> None:
         """
         Fork a child to run CGI disconnected for polling update method.
         Force parent process to exit.
@@ -397,7 +394,7 @@ class Screen(BaseScreen):
         s.settimeout(POLL_CONNECT)
         self.server_socket = s
 
-    def _handle_alarm(self, sig, frame):
+    def _handle_alarm(self, sig, frame) -> None:
         if self.update_method not in {"multipart", "polling child"}:
             raise ValueError(self.update_method)
         if self.update_method == "polling child":
@@ -413,7 +410,7 @@ class Screen(BaseScreen):
             sys.stdout.flush()
         signal.alarm(ALARM_DELAY)
 
-    def get_cols_rows(self):
+    def get_cols_rows(self) -> tuple[int, int]:
         """Return the screen size."""
         return self.screen_size
 
@@ -437,7 +434,7 @@ class Screen(BaseScreen):
                 return [], []
             return []
 
-        keydata = os.read(self.input_fd, MAX_READ)
+        keydata = os.read(self.input_fd, MAX_READ).decode(get_encoding())
         os.close(self.input_fd)
         self.input_fd = os.open(f"{self.pipe_name}.in", os.O_NONBLOCK | os.O_RDONLY)
         # sys.stderr.write( repr((keydata,self.input_tail))+"\n" )
@@ -462,7 +459,7 @@ class Screen(BaseScreen):
         return pending_input
 
 
-def code_span(s, fg, bg, cursor=-1):
+def code_span(s, fg, bg, cursor=-1) -> str:
     code_fg = _code_colours[fg]
     code_bg = _code_colours[bg]
 
@@ -488,22 +485,14 @@ def code_span(s, fg, bg, cursor=-1):
     return f"{code_fg + code_bg + s}\n"
 
 
-def html_escape(text):
-    """Escape text so that it will be displayed safely within HTML"""
-    text = text.replace("&", "&amp;")
-    text = text.replace("<", "&lt;")
-    text = text.replace(">", "&gt;")
-    return text
-
-
-def is_web_request():
+def is_web_request() -> bool:
     """
     Return True if this is a CGI web request.
     """
     return "REQUEST_METHOD" in os.environ
 
 
-def handle_short_request():
+def handle_short_request() -> bool:
     """
     Handle short requests such as passing keystrokes to the application
     or sending the initial html page.  If returns True, then this
@@ -518,7 +507,7 @@ def handle_short_request():
 
     if os.environ["REQUEST_METHOD"] == "GET":
         # Initial request, send the HTML and javascript.
-        sys.stdout.write("Content-type: text/html\r\n\r\n" + html_escape(_prefs.app_name).join(_html_page))
+        sys.stdout.write("Content-type: text/html\r\n\r\n" + html.escape(_prefs.app_name).join(_html_page))
         return True
 
     if os.environ["REQUEST_METHOD"] != "POST":
@@ -616,7 +605,7 @@ class ErrorLog:
             f.write(err)
 
 
-def daemonize(errfile):
+def daemonize(errfile: str) -> None:
     """
     Detach process and become a daemon.
     """
@@ -637,6 +626,6 @@ def daemonize(errfile):
         with suppress(OSError):
             os.close(fd)
 
-    sys.stdin = open("/dev/null", encoding="utf-8")  # noqa: SIM115
-    sys.stdout = open("/dev/null", "w", encoding="utf-8")  # noqa: SIM115
+    sys.stdin = open("/dev/null", encoding="utf-8")  # noqa: SIM115  # pylint: disable=consider-using-with
+    sys.stdout = open("/dev/null", "w", encoding="utf-8")  # noqa: SIM115  # pylint: disable=consider-using-with
     sys.stderr = ErrorLog(errfile)
