@@ -27,28 +27,27 @@ import typing
 import warnings
 from contextlib import suppress
 
+from urwid import str_util
+
 if typing.TYPE_CHECKING:
     from collections.abc import Generator, Iterable
     from types import TracebackType
 
-    from typing_extensions import Protocol, Self
+    from typing_extensions import Literal, Protocol, Self
 
     class CanBeStopped(Protocol):
         def stop(self) -> None: ...
 
 
-try:
-    from urwid import str_util
-except ImportError:
-    from urwid import old_str_util as str_util
-
-# bring str_util functions into our namespace
-calc_text_pos = str_util.calc_text_pos
-calc_width = str_util.calc_width
-is_wide_char = str_util.is_wide_char
-move_next_char = str_util.move_next_char
-move_prev_char = str_util.move_prev_char
-within_double_byte = str_util.within_double_byte
+def __getattr__(name: str) -> typing.Any:
+    if hasattr(str_util, name):
+        warnings.warn(
+            f"Do not import {name!r} from {__package__}.{__name__}, import it from 'urwid'.",
+            DeprecationWarning,
+            stacklevel=3,
+        )
+        return getattr(str_util, name)
+    raise AttributeError(f"{name} is not defined in {__package__}.{__name__}")
 
 
 def detect_encoding() -> str:
@@ -100,7 +99,7 @@ def set_encoding(encoding: str) -> None:
     """
     encoding = encoding.lower()
 
-    global _target_encoding, _use_dec_special  # noqa: PLW0603
+    global _target_encoding, _use_dec_special  # noqa: PLW0603  # noqa: PLW0603  # pylint: disable=global-statement
 
     if encoding in {"utf-8", "utf8", "utf"}:
         str_util.set_byte_encoding("utf8")
@@ -144,7 +143,7 @@ def get_encoding() -> str:
 
 
 @contextlib.contextmanager
-def set_temporary_encoding(encoding_name: str) -> Generator[None, None, None]:
+def set_temporary_encoding(encoding_name: str) -> Generator[None]:
     """Internal helper for encoding specific validation in unittests/doctests.
 
     Not exported globally.
@@ -157,7 +156,7 @@ def set_temporary_encoding(encoding_name: str) -> Generator[None, None, None]:
         set_encoding(old_encoding)
 
 
-def get_encoding_mode():
+def get_encoding_mode() -> Literal["wide", "narrow", "utf8"]:
     """
     Get the mode Urwid is using when processing text strings.
     Returns 'narrow' for 8-bit encodings, 'wide' for CJK encodings
@@ -166,7 +165,7 @@ def get_encoding_mode():
     return str_util.get_byte_encoding()
 
 
-def apply_target_encoding(s: str | bytes):
+def apply_target_encoding(s: str | bytes) -> tuple[bytes, list[tuple[Literal["U", "0"] | None, int]]]:
     """
     Return (encoded byte string, character set rle).
     """
@@ -188,9 +187,6 @@ def apply_target_encoding(s: str | bytes):
 
     sis = s.split(SO)
 
-    if not isinstance(sis[0], bytes):
-        raise TypeError(sis[0])
-
     sis0 = sis[0].replace(SI, b"")
     sout = []
     cout = []
@@ -202,24 +198,19 @@ def apply_target_encoding(s: str | bytes):
         return sis0, cout
 
     for sn in sis[1:]:
-        if not isinstance(sn, bytes):
-            raise TypeError(sn)
-        if not isinstance(SI, bytes):
-            raise TypeError(SI)
-
         sl = sn.split(SI, 1)
         if len(sl) == 1:
             sin = sl[0]
-            if not isinstance(sin, bytes):
-                raise TypeError(sin)
             sout.append(sin)
             rle_append_modify(cout, (escape.DEC_TAG, len(sin)))
             continue
+
         sin, son = sl
         son = son.replace(SI, b"")
         if sin:
             sout.append(sin)
             rle_append_modify(cout, (escape.DEC_TAG, len(sin)))
+
         if son:
             sout.append(son)
             rle_append_modify(cout, (None, len(son)))
@@ -265,12 +256,12 @@ def calc_trim_text(
     spos = start_offs
     pad_left = pad_right = 0
     if start_col > 0:
-        spos, sc = calc_text_pos(text, spos, end_offs, start_col)
+        spos, sc = str_util.calc_text_pos(text, spos, end_offs, start_col)
         if sc < start_col:
             pad_left = 1
-            spos, sc = calc_text_pos(text, start_offs, end_offs, start_col + 1)
+            spos, sc = str_util.calc_text_pos(text, start_offs, end_offs, start_col + 1)
     run = end_col - start_col - pad_left
-    pos, sc = calc_text_pos(text, spos, end_offs, run)
+    pos, sc = str_util.calc_text_pos(text, spos, end_offs, run)
     if sc < run:
         pad_right = 1
     return (spos, pos, pad_left, pad_right)
