@@ -7,7 +7,11 @@ from urwid import text_layout
 from urwid.canvas import CompositeCanvas
 from urwid.command_map import Command
 from urwid.split_repr import remove_defaults
-from urwid.util import decompose_tagmarkup, is_wide_char, move_next_char, move_prev_char
+from urwid.str_util import is_wide_char, move_next_char, move_prev_char
+from urwid.util import decompose_tagmarkup
+
+from .constants import Align, Sizing, WrapMode
+from .text import Text, TextError
 
 if typing.TYPE_CHECKING:
     from collections.abc import Hashable
@@ -16,9 +20,6 @@ if typing.TYPE_CHECKING:
 
     from urwid.canvas import TextCanvas
 
-from .constants import Align, Sizing, WrapMode
-from .text import Text, TextError
-
 
 class EditError(TextError):
     pass
@@ -112,7 +113,7 @@ class Edit(Text):
         self._edit_pos = 0
         self._caption, self._attrib = decompose_tagmarkup(caption)
         self._edit_text = ""
-        self.highlight = None
+        self.highlight: tuple[int, int] | None = None
         self.set_edit_text(edit_text)
         if edit_pos is None:
             edit_pos = len(edit_text)
@@ -129,7 +130,7 @@ class Edit(Text):
         )
 
     def _repr_attrs(self) -> dict[str, typing.Any]:
-        attrs = dict(super()._repr_attrs(), edit_pos=self._edit_pos)
+        attrs = {**super()._repr_attrs(), "edit_pos": self._edit_pos}
         return remove_defaults(attrs, Edit.__init__)
 
     def get_text(self) -> tuple[str | bytes, list[tuple[Hashable, int]]]:
@@ -152,7 +153,7 @@ class Edit(Text):
 
         return self._caption + (self._mask * len(self._edit_text)), self._attrib
 
-    def set_text(self, markup: tuple[str, list[tuple[Hashable, int]]]) -> None:
+    def set_text(self, markup: str | tuple[Hashable, str] | list[str | tuple[Hashable, str]]) -> None:
         """
         Not supported by Edit widget.
 
@@ -259,10 +260,7 @@ class Edit(Text):
         >>> e.edit_pos
         4
         """
-        if pos < 0:
-            pos = 0
-        if pos > len(self._edit_text):
-            pos = len(self._edit_text)
+        pos = min(max(pos, 0), len(self._edit_text))
         self.highlight = None
         self.pref_col_maxcol = None, None
         self._edit_pos = pos
@@ -310,8 +308,8 @@ class Edit(Text):
         self._emit("change", text)
         old_text = self._edit_text
         self._edit_text = text
-        if self.edit_pos > len(text):
-            self.edit_pos = len(text)
+        self.edit_pos = min(self.edit_pos, len(text))
+
         self._emit("postchange", old_text)
         self._invalidate()
 
@@ -361,10 +359,7 @@ class Edit(Text):
         self.highlight = None
 
     def _normalize_to_caption(self, text: str | bytes) -> str | bytes:
-        """
-        Return text converted to the same type as self.caption
-        (bytes or unicode)
-        """
+        """Return text converted to the same type as self.caption (bytes or unicode)"""
         tu = isinstance(text, str)
         cu = isinstance(self._caption, str)
         if tu == cu:
@@ -386,7 +381,7 @@ class Edit(Text):
         # if there's highlighted text, it'll get replaced by the new text
         text = self._normalize_to_caption(text)
         if self.highlight:
-            start, stop = self.highlight
+            start, stop = self.highlight  # pylint: disable=unpacking-non-sequence  # already checked
             btext, etext = self.edit_text[:start], self.edit_text[stop:]
             result_text = btext + etext
             result_pos = start
@@ -402,7 +397,11 @@ class Edit(Text):
         result_pos += len(text)
         return (result_text, result_pos)
 
-    def keypress(self, size: tuple[int], key: str) -> str | None:
+    def keypress(
+        self,
+        size: tuple[int],  # type: ignore[override]
+        key: str,
+    ) -> str | None:
         """
         Handle editing keystrokes, return others.
 
@@ -423,9 +422,6 @@ class Edit(Text):
         pos = self.edit_pos
         if self.valid_char(key):
             if isinstance(key, str) and not isinstance(self._caption, str):
-                # screen is sending us unicode input, must be using utf-8
-                # encoding because that's all we support, so convert it
-                # to bytes to match our caption's type
                 key = key.encode("utf-8")
             self.insert_text(key)
             return None
@@ -540,11 +536,7 @@ class Edit(Text):
             return False
 
         pos = text_layout.calc_pos(self.get_text()[0], trans, x, y)
-        e_pos = pos - len(self.caption)
-        if e_pos < 0:
-            e_pos = 0
-        if e_pos > len(self.edit_text):
-            e_pos = len(self.edit_text)
+        e_pos = min(max(pos - len(self.caption), 0), len(self.edit_text))
         self.edit_pos = e_pos
         self.pref_col_maxcol = x, maxcol
         self._invalidate()
@@ -552,11 +544,11 @@ class Edit(Text):
 
     def mouse_event(
         self,
-        size: tuple[int],
+        size: tuple[int],  # type: ignore[override]
         event: str,
         button: int,
-        x: int,
-        y: int,
+        col: int,
+        row: int,
         focus: bool,
     ) -> bool | None:
         """
@@ -570,7 +562,7 @@ class Edit(Text):
         2
         """
         if button == 1:
-            return self.move_cursor_to_coords(size, x, y)
+            return self.move_cursor_to_coords(size, col, row)
         return False
 
     def _delete_highlighted(self) -> bool:
@@ -580,14 +572,18 @@ class Edit(Text):
         """
         if not self.highlight:
             return False
-        start, stop = self.highlight
+        start, stop = self.highlight  # pylint: disable=unpacking-non-sequence  # already checked
         btext, etext = self.edit_text[:start], self.edit_text[stop:]
         self.set_edit_text(btext + etext)
         self.edit_pos = start
         self.highlight = None
         return True
 
-    def render(self, size: tuple[int], focus: bool = False) -> TextCanvas | CompositeCanvas:
+    def render(
+        self,
+        size: tuple[int],  # type: ignore[override]
+        focus: bool = False,
+    ) -> TextCanvas | CompositeCanvas:
         """
         Render edit widget and return canvas.  Include cursor when in
         focus.
@@ -599,7 +595,7 @@ class Edit(Text):
         >>> c.cursor
         (5, 0)
         """
-        self._shift_view_to_cursor = bool(focus)
+        self._shift_view_to_cursor = bool(focus)  # noqa: FURB123,RUF100
 
         canv: TextCanvas | CompositeCanvas = super().render(size, focus)
         if focus:
@@ -685,7 +681,11 @@ class IntEdit(Edit):
             val = ""
         super().__init__(caption, val)
 
-    def keypress(self, size: tuple[int], key: str) -> str | None:
+    def keypress(
+        self,
+        size: tuple[int],  # type: ignore[override]
+        key: str,
+    ) -> str | None:
         """
         Handle editing keystrokes.  Remove leading zeros.
 
